package init_serve

import (
	"github.com/gin-gonic/gin"
	"github.com/swaggo/gin-swagger"
	"github.com/swaggo/gin-swagger/swaggerFiles"
	_ "hongze/hrms_api/docs"
	"hongze/hrms_api/global"
	"hongze/hrms_api/middleware"
	"hongze/hrms_api/routers"
)

// InitRouter 初始化路由
func InitRouter() (r *gin.Engine) {
	//设置
	gin.SetMode(global.CONFIG.Serve.RunMode)
	// 1.创建路由
	r = gin.Default()
	r.Use(middleware.Cors())
	//r.Use(gin.Recovery())
	r.Use(middleware.Recover())

	// 公共的中间件
	r.Use(middleware.Common())

	//swagger界面访问地址 http://localhost:8390/swagger/index.html
	r.GET("/swagger/*any", ginSwagger.WrapHandler(swaggerFiles.Handler))
	rBase := r.Group("api/")
	//系统相关路由
	systemGroup := rBase.Group("system/")
	rcrtGroup := rBase.Group("rcrt/")
	resourceGroup := rBase.Group("resource/")
	routers.InitSystem(systemGroup)
	routers.InitAuth(rBase)
	routers.InitResource(resourceGroup)
	routers.InitRcrt(rcrtGroup)
	return
}
